<?php
/*!
 * Initializing Redux framework options for Theme Options
 * Author Realtyna Inc.
 * Copyright 2019 Realtyna Inc. | realtyna.com
 */
// Exit if accessed directly.
if(!defined('ABSPATH')) exit;

/**
 * ReduxFramework
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

// Return if Redux is not exist
if(!class_exists('Redux')) return;

// This is your option name where all the Redux data is stored.
$sesame_opt_name = "sesame_options";

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 **/

$sesame_theme = wp_get_theme(); // For use with some settings. Not necessary.

$sesame_args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name'             => $sesame_opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name'         => $sesame_theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version'      => $sesame_theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type'            => 'menu',
    // Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu'       => true,
    // Disable Tracking
    'disable_tracking'     => true,
    // Show the sections below the admin menu item or not
    'menu_title'           => __('Sesame Options', 'sesame'),
    'page_title'           => __('Sesame Options', 'sesame'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key'       => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography'     => true,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar'            => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon'       => '',
    // Choose an icon for the admin bar menu
    'admin_bar_priority'   => 50,
    // Choose an priority for the admin bar menu
    'global_variable'      => $sesame_opt_name,
    // Set a different name for your global variable other than the sesame_opt_name
    'dev_mode'             => false,
    // Show the time the page took to load, etc
    'update_notice'        => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer'           => true,
    'customizer_only'      => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

    // OPTIONAL -> Give you extra features
    'page_priority'        => 59,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent'          => '',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions'     => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon'            => get_template_directory_uri().'/assets/img/svg/admin-logo.svg',
    // Specify a custom URL to an icon
    'last_tab'             => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon'            => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug'            => 'sesame_options',
    // Page slug used to denote the panel
    'save_defaults'        => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show'         => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark'         => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export'   => true,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time'       => 60 * MINUTE_IN_SECONDS,
    'output'               => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag'           => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    /* translators: %s is the name of theme author */
    'footer_credit'     => sprintf(__('Sesame theme is developed by %s.', 'sesame'), '<a href="https://realtyna.com" target="_blank">'.esc_html__('Realtyna', 'sesame').'</a>'),                   // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database'             => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!

    'use_cdn'              => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    //'compiler'             => true,

    // HINTS
    'hints'                => array(
        'icon'          => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color'    => 'lightgray',
        'icon_size'     => 'normal',
        'tip_style'     => array(
            'color'   => 'light',
            'shadow'  => true,
            'rounded' => false,
            'style'   => '',
        ),
        'tip_position'  => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect'    => array(
            'show' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'mouseover',
            ),
            'hide' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'click mouseleave',
            ),
        ),
    ),
    
    'templates_path' => get_template_directory().'/includes/redux_template/',
    'show_options_object' => false
);

// ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
$sesame_args['admin_bar_links'][] = array(
    'id'    => 'sesame-author',
    'href'  => 'https://realtyna.com/',
    'title' => __('Realtyna', 'sesame'),
);

// Panel Intro text -> before the form
$sesame_args['intro_text'] = '';

// Add content after the form.
$sesame_args['footer_text'] = '';

Redux::setArgs( $sesame_opt_name, $sesame_args );

/*
 * <--- END ARGUMENTS
 */

/*
 * ---> START HELP TABS
 */

// Set the help sidebar
$sesame_content = '';
Redux::setHelpSidebar($sesame_opt_name, $sesame_content);

/*
 * <--- END HELP TABS
 */

/*
 *
 * ---> START SECTIONS
 *
 */

Redux::setSection($sesame_opt_name, sesame_get_fields()->section_general_options);
Redux::setSection($sesame_opt_name, sesame_get_fields()->section_colors_options);
Redux::setSection($sesame_opt_name, sesame_get_fields()->section_fonts_options);
Redux::setSection($sesame_opt_name, sesame_get_fields()->section_page_title_options);
Redux::setSection($sesame_opt_name, sesame_get_fields()->section_header_options);
Redux::setSection($sesame_opt_name, sesame_get_fields()->section_footer_options);
Redux::setSection($sesame_opt_name, sesame_get_fields()->section_sidebar_options);
Redux::setSection($sesame_opt_name, sesame_get_fields()->section_blog_options);
Redux::setSection($sesame_opt_name, sesame_get_fields()->section_social_options);

/*
 * <--- END SECTIONS
 */